@@ -14,6 +14,7 @@ from keras_cv_attention_models import edgenext
 from keras_cv_attention_models import efficientformer
 from keras_cv_attention_models import efficientdet
 from keras_cv_attention_models import gcvit
+from keras_cv_attention_models import ghostnetv2
 from keras_cv_attention_models import halonet
 from keras_cv_attention_models import hornet
 from keras_cv_attention_models import levit
@@ -41,6 +42,7 @@ from keras_cv_attention_models import uniformer
 from keras_cv_attention_models import volo
 from keras_cv_attention_models import yolox
 from keras_cv_attention_models import yolor
+from keras_cv_attention_models import yolov7
 from keras_cv_attention_models import download_and_load
 from keras_cv_attention_models import visualizing
 from keras_cv_attention_models import imagenet
