@@ -193,37 +193,31 @@ def keras_reload_stacked_state_dict(model, stacked_state_dict, layer_names_match
         model.save(save_name)
 
 
-def try_save_pth_and_onnx(torch_model, save_pth=True, save_onnx=True, input_shape=(224, 224)):
+def try_save_pth_and_onnx(torch_model, save_pth=True, save_onnx=True, input_shape=(10, 3, 224, 224), dtype="float32", save_name=None):
     import torch
+    import numpy as np
 
-    input_shape = input_shape[:2]
+    save_name = torch_model.__class__.__name__ if save_name is None else save_name
+    dummy_inputs = torch.from_numpy(np.random.uniform(size=input_shape).astype(dtype))
     if save_pth:
-        try:
-            output_name = torch_model.__class__.__name__ + ".pth"
-            traced_cell = torch.jit.trace(torch_model, (torch.randn(10, 3, *input_shape)))
-            torch.jit.save(traced_cell, output_name)
-            print(">>>> Saved to:", output_name)
-        except:
-            print(">>>> Saved pth failed")
-            pass
+        output_name = save_name + ".pth"
+        traced_cell = torch.jit.trace(torch_model, (dummy_inputs))
+        torch.jit.save(traced_cell, output_name)
+        print(">>>> Saved to:", output_name)
 
     if save_onnx:
-        try:
-            output_name = torch_model.__class__.__name__ + ".onnx"
-            torch.onnx.export(
-                model=torch_model,
-                args=torch.randn(10, 3, *input_shape),
-                f=output_name,
-                verbose=False,
-                keep_initializers_as_inputs=True,
-                training=torch.onnx.TrainingMode.PRESERVE,
-                do_constant_folding=False,
-                opset_version=13,
-            )
-            print(">>>> Saved to:", output_name)
-        except:
-            print(">>>> Saved onnx failed")
-            pass
+        output_name = save_name + ".onnx"
+        torch.onnx.export(
+            model=torch_model,
+            args=dummy_inputs,
+            f=output_name,
+            verbose=False,
+            keep_initializers_as_inputs=True,
+            training=torch.onnx.TrainingMode.PRESERVE,
+            do_constant_folding=False,
+            opset_version=13,
+        )
+        print(">>>> Saved to:", output_name)
 
 
 def keras_reload_from_torch_model(
@@ -239,6 +233,7 @@ def keras_reload_from_torch_model(
     specific_match_func=None,
     save_name=None,
     do_convert=True,
+    do_predict=True,
 ):
     import torch
     import numpy as np
@@ -253,23 +248,25 @@ def keras_reload_from_torch_model(
     is_state_dict = isinstance(torch_model, dict)
 
     """ Chelsea the cat  """
-    img = test_images.cat()
-    img = keras.applications.imagenet_utils.preprocess_input(tf.image.resize(img, input_shape), mode="torch").numpy()
+    if do_predict:
+        img = test_images.cat()
+        img = keras.applications.imagenet_utils.preprocess_input(tf.image.resize(img, input_shape), mode="torch").numpy()
 
     if not is_state_dict:
         _ = torch_model.eval()
         state_dict = torch_model.state_dict()
 
-        try:
-            # from torchsummary import summary
-            # summary(torch_model, (3, *input_shape), device="cpu")
-            """Torch Run predict"""
-            out = torch_model(torch.from_numpy(np.expand_dims(img.transpose(2, 0, 1), 0).astype("float32")))
-            out = out.detach().cpu().numpy()
-            # out = tf.nn.softmax(out).numpy()  # If classifier activation is not softmax
-            torch_out = keras.applications.imagenet_utils.decode_predictions(out)
-        except:
-            pass
+        if do_predict:
+            try:
+                # from torchsummary import summary
+                # summary(torch_model, (3, *input_shape), device="cpu")
+                """Torch Run predict"""
+                out = torch_model(torch.from_numpy(np.expand_dims(img.transpose(2, 0, 1), 0).astype("float32")))
+                out = out.detach().cpu().numpy()
+                # out = tf.nn.softmax(out).numpy()  # If classifier activation is not softmax
+                torch_out = keras.applications.imagenet_utils.decode_predictions(out)
+            except:
+                pass
     else:
         state_dict = torch_model
 
@@ -312,12 +309,13 @@ def keras_reload_from_torch_model(
     print()
 
     """ Keras run predict """
-    try:
-        pred = keras_model(tf.expand_dims(img, 0)).numpy()
-        # pred = tf.nn.softmax(pred).numpy()  # If classifier activation is not softmax
-        print(">>>> Keras model prediction:", keras.applications.imagenet_utils.decode_predictions(pred)[0])
-        print()
-        if not is_state_dict:
-            print(">>>> Torch model prediction:", torch_out)
-    except:
-        pass
+    if do_predict:
+        try:
+            pred = keras_model(tf.expand_dims(img, 0)).numpy()
+            # pred = tf.nn.softmax(pred).numpy()  # If classifier activation is not softmax
+            print(">>>> Keras model prediction:", keras.applications.imagenet_utils.decode_predictions(pred)[0])
+            print()
+            if not is_state_dict:
+                print(">>>> Torch model prediction:", torch_out)
+        except:
+            pass
