@@ -13,7 +13,7 @@ from keras_cv_attention_models.model_surgery.model_surgery import (
     get_actual_drop_connect_rates,
     get_flops,
     get_global_avg_pool_layer_id,
-    get_pyramide_feture_layers,
+    get_pyramide_feature_layers,
     prepare_for_tflite,
     print_model_params_count,
     replace_ReLU,
